<?php

namespace Drupal\s3fs_file_proxy_to_s3;

use Drupal\Component\Utility\UrlHelper;
use Drupal\stage_file_proxy\FetchManager;

class S3fsFileProxyToS3FetchManager extends FetchManager {

  /**
   * {@inheritdoc}
   */
  public function fetch($server, $remote_file_dir, $relative_path) {
    // Fetch remote file.
    $remote_file_dir = $this->fileAmazonPath();
    $url = $server . '/' . UrlHelper::encodePath($remote_file_dir . '/' . $relative_path);
    $response = $this->client->get($url);

    if ($response->getStatusCode() == 200) {
      // Prepare local target directory and save downloaded file.
      $file_dir = $this->filePublicDestination();
      $target_dir = $file_dir . dirname($relative_path);
      if (file_prepare_directory($target_dir, FILE_CREATE_DIRECTORY | FILE_MODIFY_PERMISSIONS)) {
        file_put_contents($file_dir . $relative_path, $response->getBody(TRUE));
        return TRUE;
      }
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function filePublicPath() {
    return 's3fs_to_s3/files';
  }

  private function filePublicDestination() {
    return 'public://';
  }

  private function fileAmazonPath() {
    $publicAmazonPath = \Drupal::config('s3fs.settings')->get('public_folder');

    if (!$publicAmazonPath) {
      $publicAmazonPath = 's3fs-public';
    }
    return $publicAmazonPath;
  }

  /**
   * {@inheritdoc}
   */
  public function styleOriginalPath($uri, $style_only = TRUE) {
    $scheme = file_uri_scheme($uri);
    if ($scheme) {
      $path = file_uri_target($uri);
    }
    else {
      $path = $uri;
      $scheme = file_default_scheme();
    }

    // It is a styles path, so we extract the different parts.
    if (strpos($path, 's3fs_to_s3/files/styles') === 0) {
      // Then the path is like styles/[style_name]/[schema]/[original_path].
      return preg_replace('/s3fs_to_s3\/files\/styles\/.*\/(.*)\/(.*)/U', '$1://$2', $path);
    }
    // Else it seems to be the original.
    elseif ($style_only == FALSE) {
      return "$scheme://$path";
    }
    else {
      return FALSE;
    }
  }

}
